@@ -19,7 +19,7 @@
 """
 import logging
 
-from argos.config.abstractcti import AbstractCti, AbstractCtiEditor, InvalidInputError
+from argos.config.abstractcti import AbstractCti, AbstractCtiEditor
 from argos.config.boolcti import BoolCti
 from argos.config.choicecti import ChoiceCti
 from argos.config.intcti import IntCti
@@ -27,6 +27,7 @@ from argos.config.floatcti import FloatCti
 from argos.info import DEBUGGING
 from argos.qt import Qt, QtCore, QtGui, QtWidgets, QtSlot
 from argos.utils.cls import check_is_a_string
+from argos.utils.defs import InvalidInputError
 
 
 
@@ -76,7 +77,7 @@ def fontFamilyIndex(qFont, families):
         if False and DEBUGGING:
             raise
         else:
-            logger.warn("{} not found in font families, using default.".format(qFont.family()))
+            logger.warning("{} not found in font families, using default.".format(qFont.family()))
             return families.index(qFont.defaultFamily())
 
 
@@ -91,7 +92,7 @@ def fontWeightIndex(qFont, weights):
         if False and DEBUGGING:
             raise
         else:
-            logger.warn("{} not found in font weights, using normal.".format(qFont.weight()))
+            logger.warning("{} not found in font weights, using normal.".format(qFont.weight()))
             return weights.index(QtGui.QFont.Normal)
 
 
@@ -107,7 +108,7 @@ class ColorCti(AbstractCti):
     def _enforceDataType(self, data):
         """ Converts to str so that this CTI always stores that type.
         """
-        qColor = QtGui.QColor(data)    # TODO: store a RGB string?
+        qColor = QtGui.QColor(data)
         if not qColor.isValid():
             raise ValueError("Invalid color specification: {!r}".format(data))
         return qColor
@@ -124,22 +125,16 @@ class ColorCti(AbstractCti):
         return self.data
 
 
-    def _nodeGetNonDefaultsDict(self):
-        """ Retrieves this nodes` values as a dictionary to be used for persistence.
-            Non-recursive auxiliary function for getNonDefaultsDict
+    def _nodeMarshall(self):
+        """ Returns the non-recursive marshalled value of this CTI. Is called by marshall()
         """
-        dct = {}
-        if self.data != self.defaultData:
-            dct['data'] = self.data.name()
-        return dct
+        return self.data.name()
 
 
-    def _nodeSetValuesFromDict(self, dct):
-        """ Sets values from a dictionary in the current node.
-            Non-recursive auxiliary function for setValuesFromDict
+    def _nodeUnmarshall(self, data):
+        """ Initializes itself non-recursively from data. Is called by unmarshall()
         """
-        if 'data' in dct:
-            self.data = QtGui.QColor(dct['data'])
+        self.data = QtGui.QColor(data)
 
 
     def createEditor(self, delegate, parent, option):
@@ -151,7 +146,7 @@ class ColorCti(AbstractCti):
 
 
 class ColorCtiEditor(AbstractCtiEditor):
-    """ A CtiEditor which contains a QCombobox for editing ColorCti objects.
+    """ A CtiEditor which contains a QLineEdit for editing ColorCti objects.
     """
     def __init__(self, cti, delegate, parent=None):
         """ See the AbstractCtiEditor for more info on the parameters
@@ -356,12 +351,32 @@ class FontCti(AbstractCti):
             success = qFont.fromString(dct['data'])
             if not success:
                 msg = "Unable to create QFont from string {!r}".format(dct['data'])
-                logger.warn(msg)
+                logger.warning(msg)
                 if DEBUGGING:
                     raise ValueError(msg)
             self.data = qFont
 
 
+    def _nodeMarshall(self):
+        """ Returns the non-recursive marshalled value of this CTI. Is called by marshall()
+        """
+        return self.data.toString() # calls QFont.toString()
+
+
+    def _nodeUnmarshall(self, data):
+        """ Initializes itself non-recursively from data. Is called by unmarshall()
+        """
+        qFont = QtGui.QFont()
+        success = qFont.fromString(data)
+        if not success:
+            msg = "Unable to create QFont from string {!r}".format(data)
+            logger.warning(msg)
+            if DEBUGGING:
+                raise ValueError(msg)
+        self.data = qFont
+
+
+
     def createEditor(self, delegate, parent, option):
         """ Creates a FontCtiEditor.
             For the parameters see the AbstractCti documentation.
@@ -404,7 +419,7 @@ class FontCtiEditor(AbstractCtiEditor):
         """ Opens a QColorDialog for the user
         """
         currentFont = self.getData()
-        newFont, ok = QtGui.QFontDialog.getFont(currentFont, self)
+        newFont, ok = QtWidgets.QFontDialog.getFont(currentFont, self)
         if ok:
             self.setData(newFont)
         else:
@@ -416,7 +431,7 @@ class FontCtiEditor(AbstractCtiEditor):
         """ Provides the main editor widget with a data to manipulate.
         """
         # Set the data in the 'editor_data' property of the pickButton to that getData
-        # can pass the same value back into the CTI. # TODO: use a member?
+        # can pass the same value back into the CTI.
         self.pickButton.setProperty("editor_data", data)
 
 
