@@ -32,6 +32,8 @@ import os
 import os.path
 import sys
 
+import numpy as np
+
 logging.captureWarnings(True)
 
 
@@ -52,9 +54,10 @@ def browse(fileNames=None,
 
         Calls _browse() in a while loop to enable pseudo restarts in case the registry was edited.
 
-        :param fileNames: List of file names that will be added to the repository
-        :param select: a path of the repository item that will selected at start up.
-            Overrides 'open' parameter.
+        :param fileNames: List of file names that will be added to the repository. If only one
+            file or directory is given it will be selected and expanded at start up.
+        :param select: a path of the repository item that will selected and expanded at start up,
+            even if more than one file or directory is given on the command line.
         :param inspectorFullName: The full path name of the inspector that will be loaded
         :param qtStyle: name of qtStyle (E.g. fusion).
         :param styleSheet: a path to an optional Qt Cascading Style Sheet.
@@ -125,6 +128,7 @@ def _browse(fileNames=None,
     if DEBUGGING:
         argosApp.repo.insertItem(createArgosTestData())
 
+    logger.debug("Selection path: {}".format(select))
     if select:
         for mainWindow in argosApp.mainWindows:
             mainWindow.trySelectRtiByPath(select)
@@ -150,6 +154,7 @@ def main():
     """ Starts Argos main window
     """
     # Import in functions. See comments at the top for more details
+    from argos.widgets.constants import NUMPY_LINE_WIDTH
     from argos.info import DEBUGGING, PROJECT_NAME, VERSION, EXIT_CODE_RESTART, resource_directory
     from argos.utils.logs import initLogging
     from argos.utils.misc import remove_process_serial_number
@@ -246,6 +251,9 @@ def main():
     else:
         styleSheet = os.path.abspath(styleSheet)
 
+    logger.debug("Setting numpy line width to {} characters".format(NUMPY_LINE_WIDTH))
+    np.set_printoptions(linewidth=NUMPY_LINE_WIDTH)
+
     # Process -o option. Don't do this in browse. In the future we might be able to call browse()
     # from IPython. Decide at that point how to best pass these parameters.
     fileNames = []
@@ -254,10 +262,16 @@ def main():
     if args.openFile and args.openFile not in fileNames:
         fileNames.insert(0, args.openFile)
 
-    if args.openFile and not args.selectPath:
-        selectPath = os.path.basename(args.openFile)
-    else:
+    if args.selectPath:
         selectPath = args.selectPath
+        logger.debug("Using selection path from the command line: {!r}".format(selectPath))
+    else:
+        if len(fileNames) == 1:
+            selectPath = os.path.basename(os.path.normpath(fileNames[0]))  # Using normpath to remove trailing slashes.
+            logger.debug("Selection path is the only file that is given on the command line: {!r}".format(selectPath))
+        else:
+            selectPath = None
+            logger.debug("Not selecting any files (selection path = {!r})".format(selectPath))
 
     # Browse will create an ArgosApplication with one MainWindow
     browse(fileNames = fileNames,
