@@ -33,6 +33,18 @@ from argos.utils.defs import DIM_TEMPLATE
 logger = logging.getLogger(__name__)
 
 
+def lengthToSummary(length, postfix="items"):
+    """ Constructs a summary from the length of an array
+    """
+    return str(length) + " " + postfix
+
+
+def shapeToSummary(shape, postfix="elements"):
+    """ Constructs a summary from the shape of an array
+    """
+    return " × ".join([str(elem) for elem in shape]) + " " + postfix
+
+
 class BaseRti(AbstractLazyLoadTreeItem):
     """ TreeItem for use in a RepositoryTreeModel. (RTI = Repository TreeItem)
         Base node from which to derive the other types of nodes.
@@ -344,6 +356,13 @@ class BaseRti(AbstractLazyLoadTreeItem):
             return " × ".join(str(elem) for elem in chunking)
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return ""
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -351,6 +370,13 @@ class BaseRti(AbstractLazyLoadTreeItem):
         return ""
 
 
+    @property
+    def typeName(self):
+        """ String representation of the type. By default, the elementTypeName + dimensionality.
+        """
+        return self.elementTypeName + " " + self.dimensionality
+
+
     @property
     def attributes(self):
         """ The attribute dictionary.
@@ -383,6 +409,29 @@ class BaseRti(AbstractLazyLoadTreeItem):
         return ""
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+
+            The base implementation returns ''.
+        """
+        return ""
+
+
+    @property
+    def quickLook(self):
+        """ Returns a string representation fof the RTI to use in the Quik Look pane.
+        """
+        if not self.isSliceable:
+            return ""
+        else:
+            # We would like to use np.array2string so that we can use commas to separate the array
+            # elements, and can set the line length without side effects, but unfortunately
+            # np.array2string doesn't work for masked arrays.
+            # See: https://github.com/numpy/numpy/issues/11674
+            return str(self[...])
+
+
     @property
     def missingDataValue(self):
         """ Returns the value to indicate missing data.
