@@ -22,11 +22,11 @@ import logging
 from argos.qt import QtWidgets, QtCore, Qt
 from argos.repo.detailpanes import DetailTablePane
 from argos.repo.repotreemodel import RepoTreeModel
+from argos.utils.misc import replace_eol_chars
 
 logger = logging.getLogger(__name__)
 
 
-
 class PropertiesPane(DetailTablePane):
     """ Shows the properties of the selected repo tree item.
 
@@ -71,7 +71,8 @@ class PropertiesPane(DetailTablePane):
                 nameItem = QtWidgets.QTableWidgetItem(propName)
                 nameItem.setToolTip(propName)
                 table.setItem(row, self.COL_PROP_NAME, nameItem)
-                propItem = QtWidgets.QTableWidgetItem(repoModel.itemData(currentRti, row))
+                itemDataText = replace_eol_chars(repoModel.itemData(currentRti, row))
+                propItem = QtWidgets.QTableWidgetItem(itemDataText)
                 propItem.setToolTip(repoModel.itemData(currentRti, row, role=Qt.ToolTipRole))
                 table.setItem(row, self.COL_VALUE, propItem)
                 table.resizeRowToContents(row)
