@@ -22,7 +22,7 @@
 import logging, os
 import numpy as np
 
-from .baserti import BaseRti
+from .baserti import BaseRti, shapeToSummary, lengthToSummary
 from argos.repo.iconfactory import RtiIconFactory
 from argos.utils.cls import (check_is_a_sequence, check_is_a_mapping, check_is_an_array,
                                 is_a_sequence, is_a_mapping, is_an_array, type_name)
@@ -119,6 +119,13 @@ class ScalarRti(BaseRti):
         return tuple()
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "scalar"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -133,6 +140,13 @@ class ScalarRti(BaseRti):
         return getMissingDataValue(self._scalar)
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI. In this case the scalar as a string
+        """
+        return str(self._scalar)
+
+
 
 class FieldRti(BaseRti):
     """ Repository Tree Item (RTI) that contains a field in a structured numpy array.
@@ -208,6 +222,13 @@ class FieldRti(BaseRti):
         return self._array.shape + self._subArrayShape
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "field"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -245,6 +266,15 @@ class FieldRti(BaseRti):
             return value
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        if self.isSliceable:
+            return shapeToSummary(self.arrayShape)
+        else:
+            return ""
+
 
 
 
@@ -317,6 +347,13 @@ class ArrayRti(BaseRti):
         return self._array.shape
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "array"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -353,14 +390,24 @@ class ArrayRti(BaseRti):
         return childItems
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        if self.isSliceable:
+            return shapeToSummary(self.arrayShape)
+        else:
+            return ""
+
+
 
 class SliceRti(ArrayRti):
     """ Represents a slice of a numpy array (even before it's further sliced in the collector)
 
         Inherits from ArrayRti and changes little. It overrides only the icon to indicate that the
-        underlying data is the same as it's parent.
+        underlying data is the same as its parent.
     """
-    # Use ARRAY icon here, the a FIELD icon should be used when the number of dimension is equal
+    # Use ARRAY icon here, the FIELD icon should be used when the number of dimension is equal
     # to the array to which the field belongs. A slice decreases the number of dimensions.
     _defaultIconGlyph = RtiIconFactory.ARRAY
     #_defaultIconGlyph = RtiIconFactory.FIELD
@@ -435,6 +482,16 @@ class SequenceRti(BaseRti):
         return type_name(self._sequence)
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        if self._sequence is None:
+            return ""
+        else:
+            return lengthToSummary(len(self._sequence))
+
+
     def _fetchAllChildren(self):
         """ Adds a child item for each column
         """
@@ -471,6 +528,13 @@ class MappingRti(BaseRti):
         return self._attributes
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return ""  # Return empty string to be in line with directories, groups, etc
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -482,6 +546,17 @@ class MappingRti(BaseRti):
             #return type_name(self._dictionary)
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        return ""  # Don't show length info, so it has the same behaviour as directory and groups.
+        # if self._dictionary is None:
+        #     return ""
+        # else:
+        #     return lengthToSummary(len(self._dictionary))
+
+
     def _fetchAllChildren(self):
         """ Adds a child item for each item
         """
