@@ -27,6 +27,11 @@ from argos.repo.registry import ICON_COLOR_UNDEF, RtiRegItem
 from argos.utils.cls import to_string, type_name, check_class
 from argos.utils.dirs import normRealPath
 
+# The cast to int is necessary to avoid a bug in PySide, See:
+# https://bugreports.qt-project.org/browse/PYSIDE-20
+ALIGN_LEFT  = int(Qt.AlignVCenter | Qt.AlignLeft)
+ALIGN_RIGHT = int(Qt.AlignVCenter | Qt.AlignRight)
+
 
 logger = logging.getLogger(__name__)
 
@@ -35,10 +40,13 @@ class RepoTreeModel(BaseTreeModel):
         for QTreeViews. The underlying data is stored as repository tree items (BaseRti
         descendants).
     """
-    HEADERS = ["Name", "Path", "Dimensions", "Shape", "Type", "Unit", "Missing data",
-               "Chunking", "File name", "Item class", "Is open", "Error"]
-    (COL_NODE_NAME, COL_NODE_PATH, COL_DIMS, COL_SHAPE, COL_ELEM_TYPE, COL_UNIT, COL_MISSING_DATA,
-     COL_CHUNKING, COL_FILE_NAME, COL_RTI_TYPE, COL_IS_OPEN, COL_EXCEPTION) = range(len(HEADERS))
+    HEADERS = ["Name", "Path", "Dimensions", "Shape", "Kind",
+               "Element Type", "Type", "Unit", "Missing data", "Chunking", "Summary",
+               "File name", "Item class", "Is open", "Error"]
+
+    (COL_NODE_NAME, COL_NODE_PATH, COL_DIMS, COL_SHAPE, COL_KIND,
+     COL_ELEM_TYPE, COL_TYPE, COL_UNIT, COL_MISSING_DATA, COL_CHUNKING, COL_SUMMARY,
+     COL_FILE_NAME, COL_RTI_TYPE, COL_IS_OPEN, COL_EXCEPTION) = range(len(HEADERS))
 
     COL_DECORATION = COL_NODE_NAME  # Column number that contains the icon. None for no icons
 
@@ -77,8 +85,12 @@ class RepoTreeModel(BaseTreeModel):
                     return str(treeItem.isOpen)
                 else:
                     return ""
+            elif column == self.COL_KIND:
+                return treeItem.dimensionality
             elif column == self.COL_ELEM_TYPE:
                 return treeItem.elementTypeName
+            elif column == self.COL_TYPE:
+                return treeItem.typeName
             elif column == self.COL_FILE_NAME:
                 return treeItem.fileName if hasattr(treeItem, 'fileName') else ''
             elif column == self.COL_UNIT:
@@ -91,6 +103,8 @@ class RepoTreeModel(BaseTreeModel):
                 return type_name(treeItem)
             elif column == self.COL_EXCEPTION:
                 return str(treeItem.exception) if treeItem.exception else ''
+            elif column == self.COL_SUMMARY:
+                return treeItem.summary
             else:
                 raise ValueError("Invalid column: {}".format(column))
 
@@ -122,12 +136,25 @@ class RepoTreeModel(BaseTreeModel):
                 return to_string(treeItem.missingDataValue, noneFormat='') # empty str for Nones
             elif column == self.COL_RTI_TYPE:
                 return type_name(treeItem)
+            elif column == self.COL_KIND:
+                return treeItem.dimensionality
             elif column == self.COL_ELEM_TYPE:
                 return treeItem.elementTypeName
+            elif column == self.COL_TYPE:
+                return treeItem.typeName
             elif column == self.COL_FILE_NAME:
                 return treeItem.fileName if hasattr(treeItem, 'fileName') else ''
+            elif column == self.COL_SUMMARY:
+                return treeItem.summary
             else:
                 return None
+
+        elif role == Qt.TextAlignmentRole:
+            if column == self.COL_SUMMARY:
+                return ALIGN_RIGHT
+            else:
+                return ALIGN_LEFT
+
         else:
             return super(RepoTreeModel, self).itemData(treeItem, column, role=role)
 
