@@ -24,11 +24,12 @@ from argos.config.groupcti import MainGroupCti
 from argos.config.boolcti import BoolCti
 from argos.repo.detailplugins.attr import AttributesPane
 from argos.repo.detailplugins.prop import PropertiesPane
+from argos.repo.detailplugins.quicklook import QuickLookPane
 from argos.repo.registry import globalRtiRegistry
 from argos.repo.repotreemodel import RepoTreeModel
 from argos.widgets.argostreeview import ArgosTreeView
-from argos.widgets.constants import LEFT_DOCK_WIDTH,  DOCK_SPACING, DOCK_MARGIN
-from argos.widgets.constants import COL_NODE_NAME_WIDTH, COL_SHAPE_WIDTH, COL_ELEM_TYPE_WIDTH
+from argos.widgets.constants import LEFT_DOCK_WIDTH, DOCK_SPACING, DOCK_MARGIN, COL_KIND_WIDTH
+from argos.widgets.constants import COL_NODE_NAME_WIDTH, COL_ELEM_TYPE_WIDTH, COL_SUMMARY_WIDTH
 
 from argos.widgets.misc import BasePanel
 
@@ -69,11 +70,12 @@ class RepoWidget(BasePanel):
 
         self.propertiesPane = self.addDetailsPane(PropertiesPane(self.repoTreeView))
         self.attributesPane = self.addDetailsPane(AttributesPane(self.repoTreeView))
+        self.quickLookPane = self.addDetailsPane(QuickLookPane(self.repoTreeView))
 
         self.repoTreeView.sigRepoItemChanged.connect(self.repoItemChanged)
         self.tabWidget.currentChanged.connect(self.tabChanged)
 
-        self.tabWidget.setCurrentIndex(1) # Show attributes the first time the program runs
+        self.tabWidget.setCurrentIndex(2) # Show quick look tab the first time the program runs
 
 
 
@@ -160,8 +162,12 @@ class RepoTreeView(ArgosTreeView):
 
         treeHeader = self.header()
         treeHeader.resizeSection(RepoTreeModel.COL_NODE_NAME, COL_NODE_NAME_WIDTH)
-        treeHeader.resizeSection(RepoTreeModel.COL_SHAPE, COL_SHAPE_WIDTH)
+        treeHeader.resizeSection(RepoTreeModel.COL_KIND, COL_KIND_WIDTH)
         treeHeader.resizeSection(RepoTreeModel.COL_ELEM_TYPE, COL_ELEM_TYPE_WIDTH)
+        treeHeader.resizeSection(RepoTreeModel.COL_SUMMARY, COL_SUMMARY_WIDTH)
+
+        # Note: this setting is stored in the json file. Remove the config file if you want to
+        # change it.
         treeHeader.setStretchLastSection(True)
 
         headerNames = self.model().horizontalHeaders
@@ -169,8 +175,9 @@ class RepoTreeView(ArgosTreeView):
         enabled[headerNames[RepoTreeModel.COL_NODE_NAME]] = False # Cannot be unchecked
         checked = dict((name, False) for name in headerNames)
         checked[headerNames[RepoTreeModel.COL_NODE_NAME]] = True
-        checked[headerNames[RepoTreeModel.COL_SHAPE]] = True
+        checked[headerNames[RepoTreeModel.COL_KIND]] = True
         checked[headerNames[RepoTreeModel.COL_ELEM_TYPE]] = True
+        checked[headerNames[RepoTreeModel.COL_SUMMARY]] = True
         self.addHeaderContextMenu(checked=checked, enabled=enabled, checkable={})
 
         self.setContextMenuPolicy(Qt.DefaultContextMenu) # will call contextMenuEvent
@@ -200,6 +207,10 @@ class RepoTreeView(ArgosTreeView):
         self.collapseItemAction = QtWidgets.QAction("Collapse Item", self, triggered=self.collapseCurrentItem)
         self.addAction(self.collapseItemAction)
 
+        self.copyPathAction = QtWidgets.QAction("Copy Path to Clipboard", self,
+                                                triggered=self.copyPathToClipboard)
+        self.addAction(self.copyPathAction)
+
         # Connect signals
         selectionModel = self.selectionModel() # need to store reference to prevent crash in PySide
         selectionModel.currentChanged.connect(self.currentItemChanged)
@@ -288,6 +299,19 @@ class RepoTreeView(ArgosTreeView):
         return QtCore.QSize(LEFT_DOCK_WIDTH, 450)
 
 
+    @QtSlot()
+    def copyPathToClipboard(self):
+        """ Copies the path of the currently selected item to the clipboard
+        """
+        currentItem, currentIndex = self.getCurrentItem()
+        if not currentIndex.isValid():
+            return
+
+        QtWidgets.QApplication.clipboard().setText(currentItem.nodePath)
+        logger.info("Copied path to the clipboard: {}".format(currentItem.nodePath))
+
+
+
     @QtSlot()
     def openCurrentItem(self):
         """ Opens the current item in the repository.
@@ -447,7 +471,7 @@ class RepoTreeView(ArgosTreeView):
         assert hasCurrent == (currentItem is not None), \
             "If current index is valid, currentIndex may not be None" # sanity check
 
-        # Set the item in the collector, will will subsequently update the inspector.
+        # Set the item in the collector, will subsequently update the inspector.
         if hasCurrent:
             logger.info("Adding rti to collector: {}".format(currentItem.nodePath))
             self.collector.setRti(currentItem)
