@@ -25,8 +25,13 @@ import collections
 import exdir
 import numpy as np
 
+try:
+    from collections import MutableMapping
+except:
+    from collections.abc import MutableMapping # Python > 3.10
+
 from argos.repo.iconfactory import RtiIconFactory, ICON_COLOR_UNDEF
-from argos.repo.baserti import BaseRti
+from argos.repo.baserti import BaseRti, shapeToSummary
 from argos.repo.filesytemrtis import createRtiFromFileName
 from argos.repo.rtiplugins.hdf5 import dimNamesFromDataset  # We can reuse it, the exdir module follows the h5py API.
 from argos.utils.cls import check_class, is_an_array
@@ -106,7 +111,7 @@ def flattenDict(d, parent_key='', sep='/'):
     if isinstance(d,list): d = {str(i) : v for i, v in enumerate(d)}
     for k, v in d.items():
         new_key = parent_key + sep + k if parent_key else k
-        if isinstance(v, collections.MutableMapping):
+        if isinstance(v, MutableMapping):
             items.extend(flattenDict(v, new_key, sep=sep).items())
         else:
             items.append((new_key, v))
@@ -160,6 +165,13 @@ class ExdirScalarRti(BaseRti):
         return (1, )
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "scalar"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -188,6 +200,14 @@ class ExdirScalarRti(BaseRti):
         return dataSetMissingValue(self._exdirDataset)
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI. In this case the scalar as a string
+        """
+        return str(self._exdirDataset[()])
+
+
+
 class ExdirFieldRti(BaseRti):
     """ Repository Tree Item (RTI) that contains a field in a structured HDF-5 variable.
     """
@@ -269,6 +289,13 @@ class ExdirFieldRti(BaseRti):
         return self._exdirDataset.shape + self._subArrayShape
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "field"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -318,6 +345,13 @@ class ExdirFieldRti(BaseRti):
             return value
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        return shapeToSummary(self.arrayShape)
+
+
 
 class ExdirDatasetRti(BaseRti):
     """ Repository Tree Item (RTI) that contains a HDF5 dataset.
@@ -367,6 +401,13 @@ class ExdirDatasetRti(BaseRti):
         return self._exdirDataset.shape
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "array"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -424,6 +465,12 @@ class ExdirDatasetRti(BaseRti):
         return childItems
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        return shapeToSummary(self.arrayShape)
+
 
 class ExdirRawRti(BaseRti):
     """ Repository Tree Item (RTI) that contains an Exdir Raw.
