@@ -23,17 +23,21 @@
 from __future__ import absolute_import
 
 import logging, os
+
+import numpy as np
 import h5py
 
-
 from argos.repo.iconfactory import RtiIconFactory, ICON_COLOR_UNDEF
-from argos.repo.baserti import BaseRti
+from argos.repo.baserti import BaseRti, shapeToSummary
 from argos.utils.cls import to_string, check_class, is_an_array
 from argos.utils.defs import DIM_TEMPLATE, SUB_DIM_TEMPLATE, CONTIGUOUS
 from argos.utils.masks import maskedEqual
+from argos.utils.moduleinfo import versionStrToTuple
 
 logger = logging.getLogger(__name__)
 
+H5PY_MAJOR_VERSION = versionStrToTuple(h5py.__version__)[0]
+MAX_QUICK_LOOK_SIZE = 1000
 
 
 def dimNamesFromDataset(h5Dataset, useBaseName=True):
@@ -69,22 +73,51 @@ def dimNamesFromDataset(h5Dataset, useBaseName=True):
     return dimNames
 
 
-def dataSetElementType(h5Dataset):
-    """ Returns a string describing the element type of the dataset
+def dataSetType(dtype, dimensionalityString):
+    """ Returns a string describing the element type of the dataset.
+
+        Args:
+            dtype: numpy dtype of the dataset
+            dimensionalityString: e.g. 'array ', 'scalar ', 'empty '
     """
-    dtype =  h5Dataset.dtype
+    if dimensionalityString and dimensionalityString[0] != ' ':
+        dimensionalityString = ' ' + dimensionalityString
 
     if dtype.names:
-        return '<structured>'
+        return "compound{}".format(dimensionalityString)
     else:
-        if dtype.metadata and 'vlen' in dtype.metadata:
-            vlen_type = dtype.metadata['vlen']
-            try:
-                return "<vlen {}>".format(vlen_type.__name__)  # when vlen_type is a type
-            except AttributeError: #
-                return "<vlen {}>".format(vlen_type.name)      # when vlen_type is a dtype
+        if H5PY_MAJOR_VERSION <= 2:
+            # h5py version <= 2.x
+            if dtype.metadata and 'vlen' in dtype.metadata:
+                vlen_type = dtype.metadata['vlen']
+                try:
+                    return "<vlen {}>".format(vlen_type.__name__)  # when vlen_type is a type
+                except AttributeError: #
+                    return "<vlen {}>".format(vlen_type.name)      # when vlen_type is a dtype
+        else:
+            # h5py version >= 3.x
+            stringInfo = h5py.check_string_dtype(dtype)
+            if stringInfo is not None:
+                # The dimensionality will be placed before the string encoding and length because
+                # it's more important.
+                if stringInfo.length is None:
+                    return "string{} {} variable length"\
+                        .format(dimensionalityString, stringInfo.encoding)
+                else:
+                    return "string{} {} length = {}"\
+                        .format(dimensionalityString, stringInfo.encoding, stringInfo.length)
+
+            vlenType = h5py.check_vlen_dtype(dtype)
+            if vlenType is not None:
+                # Note that, currently, variable length arrays cannot be displayed in any inspector!
+                # In general, they cannot be loaded in a numpy array, only in some cases.
+                # Therefore, they are hard to handle generically. Even the h5py documentation says
+                # it's better to consider using something else if you've got the choice.
+                # See: https://docs.h5py.org/en/stable/special.html#arbitrary-vlen-data
+                return "{}{} variable length".format(vlenType, dimensionalityString)
+
+    return "{}{}".format(dtype, dimensionalityString)
 
-    return str(dtype)
 
 
 def dataSetUnit(h5Dataset):
@@ -113,9 +146,9 @@ def attrsToDict(attrs):
     """ Converts attributes to a dictionary.
 
         In case an attribute can't be read and raises and exception, the attribute value will be
-        the error message. This will make the attributes more robuts.
+        the error message. This will make the attributes more robust.
 
-        Necessary because, for instacnce, h5py may not be able to read all attributes
+        Necessary because, for instance, h5py may not be able to read all attributes
         generated by new versions of the Python netCDF4 library.
         # See: https://github.com/h5py/h5py/issues/719
     """
@@ -152,6 +185,25 @@ def dataSetMissingValue(h5Dataset):
     return None
 
 
+def _dataSetQuickLook(data, string_info):
+    """ Makes a quick look representation of a dataset.
+
+        Args:
+            data: a numpy array or scalar
+            string_info: h5py.string_dtype information read with h5py.check_string_dtype
+    """
+    if H5PY_MAJOR_VERSION <= 2:
+        return str(data) # Just convert bytes to string in h5py <= 2.x
+    else:
+        if string_info is None:
+            return str(data)  # not a string
+        else:
+            # Variable length (vlen) string datasets will yield a numpy array with object dtype.
+            # First convert to a byte array so that we can decode it.
+            bytesArray = np.char.asarray(data)
+            return str(np.char.decode(bytesArray, encoding=string_info.encoding))
+
+
 
 class H5pyScalarRti(BaseRti):
     """ Repository Tree Item (RTI) that contains a scalar HDF-5 variable.
@@ -195,11 +247,25 @@ class H5pyScalarRti(BaseRti):
         return tuple()
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "empty" if self._h5Dataset.shape is None else "scalar"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
         """
-        return dataSetElementType(self._h5Dataset)
+        return dataSetType(self._h5Dataset.dtype, '')
+
+
+    @property
+    def typeName(self):
+        """ String representation of the type. By default, the elementTypeName + dimensionality.
+        """
+        return dataSetType(self._h5Dataset.dtype, self.dimensionality)
 
 
     @property
@@ -220,7 +286,37 @@ class H5pyScalarRti(BaseRti):
     def missingDataValue(self):
         """ Returns the value to indicate missing data. None if no missing-data value is specified.
         """
-        return dataSetMissingValue(self._h5Dataset)
+        if self._h5Dataset.size > MAX_QUICK_LOOK_SIZE:
+            return "{} of {}".format(self.typeName, self.summary)
+        else:
+            return dataSetMissingValue(self._h5Dataset)
+
+
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI. In this case the scalar as a string
+        """
+        if H5PY_MAJOR_VERSION <= 2:
+            return str(self._h5Dataset[()])  # Just convert bytes to string in h5py <= 2.x
+        else:
+            # In h5py >= 3.x the encoding is known
+            string_info = h5py.check_string_dtype(self._h5Dataset.dtype)
+
+            if self._h5Dataset.shape is None:
+                return "empty dataset"
+            elif string_info is None:
+                return str(self._h5Dataset[()])  # not a string
+            else:
+                return self._h5Dataset[()].decode(string_info.encoding, errors="replace")
+
+
+    @property
+    def quickLook(self):
+        """ Returns a string representation fof the RTI to use in the Quik Look pane.
+
+            Override default so bytes are decoded to strings.
+        """
+        return self.summary
 
 
 
@@ -265,7 +361,7 @@ class H5pyFieldRti(BaseRti):
             current field. In pseudo-code, it returns: self.ncVar[index][self.nodeName].
 
             If the field itself contains a sub-array it returns:
-                self.ncVar[mainArrayIndex][self.nodeName][subArrayIndex]
+                self.dataset[mainArrayIndex][self.nodeName][subArrayIndex]
         """
         mainArrayNumDims = len(self._h5Dataset.shape)
         mainIndex = index[:mainArrayNumDims]
@@ -313,12 +409,27 @@ class H5pyFieldRti(BaseRti):
         return CONTIGUOUS if chunks is None else chunks
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "field"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
         """
         fieldName = self.nodeName
-        return str(self._h5Dataset.dtype.fields[fieldName][0])
+        return dataSetType(self._h5Dataset.dtype.fields[fieldName][0], '')
+
+
+    @property
+    def typeName(self):
+        """ String representation of the type. By default, the elementTypeName + dimensionality.
+        """
+        fieldName = self.nodeName
+        return dataSetType(self._h5Dataset.dtype.fields[fieldName][0], self.dimensionality)
 
 
     @property
@@ -371,6 +482,29 @@ class H5pyFieldRti(BaseRti):
             return value
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        return shapeToSummary(self.arrayShape)
+
+
+    @property
+    def quickLook(self):
+        """ Returns a string representation fof the RTI to use in the Quik Look pane.
+        """
+        if self._h5Dataset.size > MAX_QUICK_LOOK_SIZE:
+            return "{} of {}".format(self.typeName, self.summary)
+        else:
+            fieldArray = self._h5Dataset[self.nodeName][:]
+            subIndex = tuple([Ellipsis])
+            slicedArray = fieldArray[subIndex]
+            data = maskedEqual(slicedArray, self.missingDataValue)
+
+            string_info = h5py.check_string_dtype(self._h5Dataset.dtype)
+            return _dataSetQuickLook(data, string_info)
+
+
 
 class H5pyDatasetRti(BaseRti):
     """ Repository Tree Item (RTI) that contains a HDF5 dataset.
@@ -402,7 +536,6 @@ class H5pyDatasetRti(BaseRti):
             return RtiIconFactory.ARRAY
 
 
-
     def hasChildren(self):
         """ Returns True if the variable has a structured type, otherwise returns False.
         """
@@ -439,11 +572,25 @@ class H5pyDatasetRti(BaseRti):
         return CONTIGUOUS if chunks is None else chunks
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "array"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
         """
-        return dataSetElementType(self._h5Dataset)
+        return dataSetType(self._h5Dataset.dtype, '')
+
+
+    @property
+    def typeName(self):
+        """ String representation of the type. By default, the elementTypeName + dimensionality.
+        """
+        return dataSetType(self._h5Dataset.dtype, self.dimensionality)
 
 
     @property
@@ -481,6 +628,26 @@ class H5pyDatasetRti(BaseRti):
         return dataSetMissingValue(self._h5Dataset)
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        return shapeToSummary(self.arrayShape)
+
+
+    @property
+    def quickLook(self):
+        """ Returns a string representation fof the RTI to use in the Quik Look pane.
+        """
+        if self._h5Dataset.size > MAX_QUICK_LOOK_SIZE:
+            return "{} of {}".format(self.typeName, self.summary)
+        else:
+            data = maskedEqual(self._h5Dataset[:], self.missingDataValue)
+            string_info = h5py.check_string_dtype(self._h5Dataset.dtype)
+            return _dataSetQuickLook(data, string_info)
+
+
+
     def _fetchAllChildren(self):
         """ Fetches all fields that this variable contains.
             Only variables with a structured data type can have fields.
