@@ -23,16 +23,21 @@
 """
 from __future__ import absolute_import
 
-import logging, types
+import logging
+import math
+
 from netCDF4 import Dataset, Variable, Dimension
 
 from argos.utils.cls import check_class
-from argos.repo.baserti import BaseRti
+from argos.repo.baserti import BaseRti, shapeToSummary
 from argos.repo.iconfactory import RtiIconFactory, ICON_COLOR_UNDEF
 from argos.utils.defs import SUB_DIM_TEMPLATE, CONTIGUOUS
+from argos.utils.masks import maskedEqual
 
 logger = logging.getLogger(__name__)
 
+MAX_QUICK_LOOK_SIZE = 1000
+
 
 def ncVarAttributes(ncVar):
     """ Returns the attributes of ncdf variable
@@ -194,6 +199,13 @@ class NcdfFieldRti(BaseRti):
         return CONTIGUOUS if chunks is None else chunks
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "field"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -254,6 +266,27 @@ class NcdfFieldRti(BaseRti):
             return value
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        return shapeToSummary(self.arrayShape)
+
+
+    @property
+    def quickLook(self):
+        """ Returns a string representation fof the RTI to use in the Quik Look pane.
+        """
+        if math.prod(self._ncVar.shape) > MAX_QUICK_LOOK_SIZE:
+            return "{} of {}".format(self.typeName, self.summary)
+        else:
+            fieldArray = self._ncVar[:][self.nodeName]
+            subIndex = tuple([Ellipsis])
+            slicedArray = fieldArray[subIndex]
+            data = maskedEqual(slicedArray, self.missingDataValue)
+            return str(data)
+
+
 
 class NcdfVariableRti(BaseRti):
     """ Repository Tree Item (RTI) that contains a NCDF variable.
@@ -344,6 +377,13 @@ class NcdfVariableRti(BaseRti):
         return CONTIGUOUS if chunks is None else chunks
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "scalar" if self.nDims == 0 else "array"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -354,7 +394,7 @@ class NcdfVariableRti(BaseRti):
             # (happens e.g. in the /PROCESSOR/processing_configuration of the Trop LX files)
             return dtype.__name__
 
-        return '<structured>' if dtype.names else str(dtype)
+        return ('compound' if dtype.names else str(dtype))
 
 
     @property
@@ -378,6 +418,32 @@ class NcdfVariableRti(BaseRti):
         return variableMissingValue(self._ncVar)
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        if self.nDims == 0:
+            import numpy as np
+            return str(np.asarray(self._ncVar))  # scalar
+        else:
+            return shapeToSummary(self.arrayShape)
+
+
+    @property
+    def quickLook(self):
+        """ Returns a string representation fof the RTI to use in the Quik Look pane.
+        """
+        # In python 3.8 we can use math.prod(self._ncVar.shape)
+        product = 1
+        for elem in self._ncVar.shape:
+            product *= elem
+
+        if  product > MAX_QUICK_LOOK_SIZE:
+            return "{} of {}".format(self.typeName, self.summary)
+        else:
+            return super(NcdfVariableRti, self).quickLook
+
+
     def _fetchAllChildren(self):
         """ Fetches all fields that this variable contains.
             Only variables with a structured data type can have fields.
