@@ -27,7 +27,7 @@ import pandas as pd
 
 from pandas.core.generic import NDFrame
 
-from argos.repo.baserti import BaseRti
+from argos.repo.baserti import BaseRti, shapeToSummary
 from argos.repo.iconfactory import RtiIconFactory, ICON_COLOR_UNDEF
 from argos.utils.cls import check_class
 
@@ -91,6 +91,13 @@ class PandasIndexRti(BaseRti):
         return self._index.shape
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "index"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -102,6 +109,11 @@ class PandasIndexRti(BaseRti):
             return '<structured>' # DataFrames and Panels
 
 
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        return shapeToSummary(self.arrayShape)
 
 
 
@@ -190,6 +202,13 @@ class AbstractPandasNDFrameRti(BaseRti):
         return self._ndFrame.shape
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return "array"
+
+
     @property
     def elementTypeName(self):
         """ String representation of the element type.
@@ -200,7 +219,17 @@ class AbstractPandasNDFrameRti(BaseRti):
             try:
                 return str(self._ndFrame.dtype) # Series
             except AttributeError:
-                return '<structured>' # DataFrames and Panels
+                return 'compound' # DataFrames and Panels
+
+
+    @property
+    def summary(self):
+        """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
+        """
+        if self._ndFrame is None:
+            return ""
+        else:
+            return shapeToSummary(self.arrayShape)
 
 
     def _createIndexRti(self, index, nodeName):
