@@ -131,6 +131,13 @@ def createArgosTestData():
     parabola = 0.02 * np.square(x)
     myDict['parabola'] = parabola
 
+    myDict['array_1K'] = np.random.randn(1000)
+    myDict['array_10K'] = np.random.randn(10 * 1000)
+    myDict['array_100K'] = np.random.randn(100 * 1000)
+    myDict['array_200K'] = np.random.randn(200 * 1000)
+    myDict['array_500K'] = np.random.randn(500 * 1000)
+    myDict['array_1000K'] = np.random.randn(1000 * 1000)
+
     #masked_array = ma.arange(2400, dtype=np.float16).reshape(60, 40)
     masked_array = np.transpose(ma.ones(shape=(40, 60)) * parabola)
     masked_array[:, 0:7] = ma.masked
@@ -172,6 +179,7 @@ def createArgosTestData():
     myDict['numpy unicode array'] = np.array(['Table', u'ταБЬℓσ'])
     myDict['byte array'] = bytearray(range(256))
     myDict['bytes'] = bytes(bytearray(range(0, 256)))
+    myDict['string'] = "The quick brown fox jumps over the lazy dog!"
 
     mappingRti = MappingRti(myDict, nodeName="myDict", iconColor=ICON_COLOR_MEMORY)
 
@@ -231,7 +239,7 @@ def addPandasTestData(rti):
     pandsRti.insertChild(PandasDataFrameRti(df, 'df', iconColor=ICON_COLOR_PANDAS))
 
     if versionInfo < (0, 25, 0):
-        # Panels are depricated and completely removed from Pandas 0.25.0
+        # Panels are deprecated and completely removed from Pandas 0.25.0
         panel = pd.Panel(np.random.randn(2, 5, 4), items=['Item1', 'Item2'],
                          major_axis=pd.date_range('1/1/2000', periods=5),
                          minor_axis=['A', 'B', 'C', 'D'])
