@@ -115,7 +115,7 @@ class MainWindow(QtWidgets.QMainWindow):
         # Move window to the center of the screen
         desktopRect = QtWidgets.QApplication.desktop().availableGeometry(self)
         center = desktopRect.center()
-        self.move(center.x() - self.width () * 0.5, center.y() - self.height() * 0.5)
+        self.move(round(center.x() - self.width () * 0.5), round(center.y() - self.height() * 0.5))
 
         self.__setupMenus()
         self.__setupViews()
@@ -336,7 +336,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 try:
                     keySeq = QtGui.QKeySequence(item.shortCut.strip())
                 except Exception as ex:
-                    logger.warning("Unable to create short cut from: '{}".format(item.shortCut))
+                    logger.warning("Unable to create shortcut from: '{}".format(item.shortCut))
                 else:
                     action.setShortcut(QtGui.QKeySequence(keySeq))
 
@@ -784,9 +784,13 @@ class MainWindow(QtWidgets.QMainWindow):
             self._argosApplication.addToRecentFiles(fileNames, rtiRegItemName)
 
         fileRootIndex = None
-        logger.debug("Opening file names: {}".format(fileNames))
+
+        logger.debug("Adding files: {}".format(fileNames))
         for fileName in fileNames:
             fileRootIndex = self.argosApplication.repo.loadFile(fileName, rtiRegItem=rtiRegItem)
+
+        if len(fileNames) == 1: # Only expand and open the file if the user selected one.
+            logger.debug("Opening file: {}".format(fileNames[0]))
             self.repoWidget.repoTreeView.setExpanded(fileRootIndex, True)
 
         # Select last opened file
@@ -813,6 +817,7 @@ class MainWindow(QtWidgets.QMainWindow):
             and (None, None) is returned.
         """
         try:
+            logger.debug("Trying to select: {}".format(path))
             lastItem, lastIndex = self.repoWidget.repoTreeView.expandPath(path)
             self.repoWidget.repoTreeView.setCurrentIndex(lastIndex)
             self.repoWidget.repoTreeView.setFocus()
@@ -1036,6 +1041,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 '/myDict/structured_arr4', # gives ValueError: Unable to transform (63, 63) to dtype [('r', '|u1'), ('', '|V1'), ('b', '|u1')]
                 '/argos/trop/2015_01_07T09_29_12_svn4465_wls_prnu/ql_test_020_minutes-020-021/engDat.nc/SATELLITE_INFO/processing_events',
                 '/argos/mini_scanner_output/multiple_dimension_scales.h5', # TODO:
+                '/argos/images/eclipseclouds_tamo_2017_geo.tif', # Fails in Python 3.10. Perhaps will work later.
             ]
 
             # Don't import plugins at module level.
@@ -1043,6 +1049,10 @@ class MainWindow(QtWidgets.QMainWindow):
             from argos.inspector.pgplugins.imageplot2d import PgImagePlot2d
 
             if isinstance(self._inspector, TextInspector):
+                 # TODO: let's fix the Pandas errors when users can open a Pandas in memory.
+                skipError.append('/myDict/pandas/simple series/index')  # AttributeError: 'str' object has no attribute 'ndim'
+                skipError.append('/myDict/pandas/df/index')  # Gives AssertionError: <class 'numpy.int64'>
+                skipError.append('/myDict/pandas/df/columns')  # Gives TAttributeError: 'str' object has no attribute 'ndim'
                 skipError.append('/myDict/pandas/multi-index/index')  # Gives TypeError: len() of unsized object. Unclear whe. # TODO
                 skipError.append('/myDict/structured_masked_arr2')    # Fails with ma.copy: 'numpy.void' object has no attribute '_update_from'
                 skipError.append('/myDict/pandas/panel/major_axis')   # ValueError: object __array__ method not producing an array
@@ -1080,13 +1090,19 @@ class MainWindow(QtWidgets.QMainWindow):
             if item.nodePath in skipPaths:
                 logger.warning("Skipping node during testing: {}".format(item.nodePath))
                 return
+            else:
+                logger.debug("Not skipping node during testing: {}".format(item.nodePath))
 
             self.repoWidget.repoTreeView.setCurrentIndex(index)
-            processEvents() # Cause Qt to update UI
+            self.repoWidget.repoTreeView.setExpanded(index, True)
 
-            # Expand node to load children.
-            #self.repoWidget.repoTreeView.setExpanded(index, True)
-            #QtWidgets.qApp.processEvents() # Cause Qt to load children.
+            # Try properties, attributes and quicklook tabs
+            for idx in range(self.repoWidget.tabWidget.count()):
+                # if idx != 2:
+                #     continue
+                logger.debug("Setting repo tab index to: {}".format(idx))
+                self.repoWidget.tabWidget.setCurrentIndex(idx)
+                processEvents() # Cause Qt to update UI
 
             for rowNr in range(repoModel.rowCount(index)):
                 childIndex = repoModel.index(rowNr, 0, parentIndex=index)
@@ -1116,7 +1132,6 @@ class MainWindow(QtWidgets.QMainWindow):
                 logger.debug("Closing: {}".format(prevRootNode.nodePath))
                 prevRootNode.close()
 
-            self.repoWidget.repoTreeView.expandBranch(index = nodeIndex, expanded=True) # TODO: why necessary?
             visitNodes(nodeIndex)
 
         try:
